## Introduce
BidmadPlugin은 모바일 앱 광고 SDK인 Bidmad를 Unity에서 사용하기 위한 Plugin입니다.
Plugin을 사용하여 Flutter 모바일 앱에서 배너 / 전면 / 보상형 광고를 게재 할 수 있습니다.

*현재 버전에서는 Android만 지원하고 있으면 빠른 시일 내에 iOS를 지원할 예정입니다.

[Flutter 샘플 다운로드]()

## Programming Guide

### 1. Android Setting

#### 1.1) Build.gradle Setting
Android SDK를 적용하기 위해 Build Gradle 세팅을 추가합니다.
```java
repositories {
    ...
    google()
    jcenter()
    maven { url "https://dl.bintray.com/adop-repo/SDK" } //bidmad
    maven { url "http://devrepo.kakao.com:8088/nexus/content/groups/public/" } //Adift
    maven {
        url "s3://repo.cauly.net/releases"
        credentials(AwsCredentials) {
            accessKey "AKIAWRZUK5MFKYVSUOLB"
            secretKey "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"
        }
    } //Cauly
    maven { url "https://tapjoy.bintray.com/maven" } //Tapjoy
}

dependencies {
    ...
    implementation 'com.adop.sdk:bidmad-androidx:1.12.2'
}

```
#### 1.2) Init Channel
AndroidSDK와 통신을 위해 MainActivity에 Bidmad Channel을 설정합니다.
```java
...
import com.adop.sdk.FlutterCommon

class MainActivity: FlutterActivity() {
    private var binaryMessenger: BinaryMessenger? = null
    private var common : FlutterCommon? = null

    override fun configureFlutterEngine(@NonNull flutterEngine: FlutterEngine) {
        GeneratedPluginRegistrant.registerWith(flutterEngine);

        binaryMessenger = flutterEngine.dartExecutor.binaryMessenger

        common = FlutterCommon(this);
        common!!.initChannel(binaryMessenger)
    }
}
```

### 2. Plugin 사용하기

#### 2.1) Banner AD
다음은 Banner 광고를 요청 예시입니다.
```dart
....//Banner init
    FlutterBidmadCommon common = FlutterBidmadCommon();
    FlutterBaseBanner banner;

    common.initBannerChannel().then((value) {
      String _channelNm = value;

      banner = FlutterBaseBanner(
          channelName: _channelNm
      );

      banner.setAdInfo("Your Zone Id");

      banner.setCallbackListener(
          onLoadAd: (String zoneId){
            print("banner onLoadAd");
          },
          onFailAd: (String zoneId){
            print("banner onFailAd");
          }
      );

      //option 
      //banner.setInterval(120); //banner refresh time(60s~120s)
    });

....//Banner Load
    banner.load(position Y);
....//Banner Remove
    banner.removeAdView();
```

#### 2.2) Interstitial AD
다음은 Interstitial 광고를 요청 예시입니다.
```dart
....//Interstitial init
    FlutterBidmadCommon common = FlutterBidmadCommon();
    FlutterBaseInterstitial interstitial;

    common.initInterstitialChannel().then((value) {
      String _channelNm = value;

      interstitial = FlutterBaseInterstitial(
          channelName: _channelNm
      );

      interstitial.setAdInfo("Your Zone Id");

      interstitial.setCallbackListener(
          onLoadAd: (String zoneId){
            print("interstitial onLoadAd");
          },
          onShowAd: (String zoneId){
            print("interstitial onShowAd" );
            interstitial.load(); //Ad Reload
          },
          onCloseAd: (String zoneId){
            print("interstitial onCloseAd");
          },
          onFailAd: (String zoneId){
            print("interstitial onFailAd");
          }
      );
    });

....//Interstitial Load
    interstitial.load();
....//Interstitial Show
    interstitial.isLoaded().then((value){
      if(value){
        interstitial.show();
      }
    });
```
#### 2.3) Reward AD
다음은 Reward 광고를 요청 예시입니다.
```dart
....//Reward init
    FlutterBidmadCommon common = FlutterBidmadCommon();
    FlutterBaseReward reward;

    common.initRewardChannel().then((value) {
      String _channelNm = value;
      reward = FlutterBaseReward(
          channelName: _channelNm
      );

      reward.setAdInfo("Your Zone Id");

      reward.setCallbackListener(
          onLoadAd: (String zoneId){
            print("reward onLoadAd");
          },
          onShowAd: (String zoneId){
            print("reward onShowAd");

            reward.load();
          },
          onCompleteAd: (String zoneId){
            print("reward onCompleteAd");
          },
          onSkippedAd: (String zoneId){
            print("reward onSkippedAd");
          },
          onCloseAd: (String zoneId){
            print("reward onCloseAd");
          },
          onClickAd: (String zoneId){
            print("reward onClickAd");
          },
          onFailAd: (String zoneId){
            print("reward onFailAd");
          }
      );
    });

....//Reward Load
    reward.load();
....//Reward Show
    reward.isLoaded().then((value){
      if(value){
        reward.show();
      }
    });
```

### 3. Plugin Interface
#### 3.1 FlutterBaseBanner

*배너 광고는 FlutterBaseBanner 통해 처리되며 이를 위한 함수 목록입니다.

Function|Description
---|---
FlutterBaseBanner(@required String channelName)|FlutterBaseBanner 생성자, Channel 생성을 위한 Name을 Param으로 받습니다.
Future<void> load(int y)|배너 광고를 요청합니다. 배너 광고가 노출될 경우 높이 y에 중앙정렬된 상태로 배너가 노출됩니다.
Future<void> setInterval(int sec)|Banner Refresh 주기를 설정합니다.(60s~120s)
Future<void> setAdInfo(String zoneId)|발급받은 ZoneId를 세팅합니다.
Future<void> hideBanner()|배너 광고 View를 숨깁니다. 
Future<void> showBanner()|배너 광고 View를 노출시킵니다.
Future<void> removeBanner()|노출된 배너를 제거합니다.
void Function(String zoneId) onLoadAd|Listener를 등록했다면 배너 Load 시 등록한 Function을 호출합니다.
void Function(String zoneId) onFailAd|Listener를 등록했다면 배너 Fail 시 등록한 Function을 호출합니다.

#### 3.2 FlutterBaseInterstitial

*전면 광고는 FlutterBaseInterstitial 통해 처리되며 이를 위한 함수 목록입니다.

Function|Description
---|---
FlutterBaseInterstitial(@required String channelName)|FlutterBaseInterstitial 생성자, Channel 생성을 위한 Name을 Param으로 받습니다.
Future<void> load()|생성자에서 입력한 ZoneId로 광고를 요청합니다.
Future<void> show()Load한 광고를 노출 시킵니다.
Future<bool> isLoaded()|광고가 Load된 상태인지 체크합니다.
Future<void> setAdInfo(String zoneId)|발급받은 ZoneId를 세팅합니다.
void Function(String zoneId) onLoadAd|Listener를 등록했다면 Interstitial Load 시 등록한 Function을 호출합니다.
void Function(String zoneId) onShowAd|Listener를 등록했다면 Interstitial Show 시 등록한 Function을 호출합니다.
void Function(String zoneId) onFailAd|Listener를 등록했다면 Interstitial Fail 시 등록한 Function을 호출합니다.
void Function(String zoneId) onCloseAd|Listener를 등록했다면 Interstitial Close 시 등록한 Function을 호출합니다.

#### 3.3 FlutterBaseReward

*보상형 광고는 BidmadReward를 통해 처리되며 이를 위한 함수 목록입니다.

Function|Description
---|---
FlutterBaseReward(@required String channelName)|FlutterBaseReward 생성자, Channel 생성을 위한 Name을 Param으로 받습니다.
Future<void> load()|생성자에서 입력한 ZoneId로 광고를 요청합니다.
Future<void> show()Load한 광고를 노출 시킵니다.
Future<bool> isLoaded()|광고가 Load된 상태인지 체크합니다.
Future<void> setAdInfo(String zoneId)|발급받은 ZoneId를 세팅합니다.
void Function(String zoneId) onLoadAd|Listener를 등록했다면 Reward Load 시 등록한 Function을 호출합니다.
void Function(String zoneId) onShowAd|Listener를 등록했다면 Reward Show 시 등록한 Function을 호출합니다.
void Function(String zoneId) onFailAd|Listener를 등록했다면 Reward Fail 시 등록한 Function을 호출합니다.
void Function(String zoneId) onCompleteAd|Listener를 등록했다면 Reward Complete 시 등록한 Function을 호출합니다.
void Function(String zoneId) onCloseAd|Listener를 등록했다면 Reward Close 시 등록한 Function을 호출합니다.
void Function(String zoneId) onClickAd|Listener를 등록했다면 Reward Click 시 등록한 Function을 호출합니다.
void Function(String zoneId) onSkipAd|Listener를 등록했다면 Reward Skip 시 등록한 Function을 호출합니다.\

#### 3.4 FlutterBidmadCommon

*앱 추적 투명성 승인 요청에 관한 함수는 BidmadCommon을 통해 제공됩니다.

Function|Description
---|---
FlutterBidmadCommon()|FlutterBidmadCommon 생성자
Future<void> setDebugging(bool isDebug)|Debugging 로그를 출력
Future<String> initBannerChannel()|Banner 광고에 관한 컨트롤을 위한 Channel 생성
Future<String> initInterstitialChannel()|Interstitial 광고에 관한 컨트롤을 위한 Channel 생성
Future<String> initRewardChannel()|Reward 광고에 관한 컨트롤을 위한 Channel 생성
